<template>
    <div class="content">
        <div class="container-fluid">
            <div class="row">
                <div class="col-lg-3 col-md-6 col-sm-12 mb-3"">
                    <b-card>
                        <b-card-text>
                            <h4 class="mt-2 mb-3">
                                <b-icon icon="globe" scale="0.8"></b-icon>
                                Nome
                            </h4>
                            <hr>
                            <p class="mt-3">xxx</p>
                        </b-card-text>
                        <template #footer>
                            <router-link to="#">
                                Manage
                            </router-link>
                        </template>
                    </b-card>
                </div>

                <div class="col-lg-3 col-md-6 col-sm-12 mb-3"">
                    <b-card>
                        <b-card-text>
                            <h4 class="mt-2 mb-3">
                                <b-icon icon="globe" scale="0.8"></b-icon>
                                Nome
                            </h4>
                            <hr>
                            <p class="mt-3">xxx</p>
                        </b-card-text>
                        <template #footer>
                            <router-link to="#">
                                Manage
                            </router-link>
                        </template>
                    </b-card>
                </div>

                <div class="col-lg-3 col-md-6 col-sm-12 mb-3"">
                    <b-card>
                        <b-card-text>
                            <h4 class="mt-2 mb-3">
                                <b-icon icon="globe" scale="0.8"></b-icon>
                                Nome
                            </h4>
                            <hr>
                            <p class="mt-3">xxx</p>
                        </b-card-text>
                        <template #footer>
                            <router-link to="#">
                                Manage
                            </router-link>
                        </template>
                    </b-card>
                </div>

                <div class="col-lg-3 col-md-6 col-sm-12 mb-3"">
                    <b-card>
                        <b-card-text>
                            <h4 class="mt-2 mb-3">
                                <b-icon icon="globe" scale="0.8"></b-icon>
                                Nome
                            </h4>
                            <hr>
                            <p class="mt-3">xxx</p>
                        </b-card-text>
                        <template #footer>
                            <router-link to="#">
                                Manage
                            </router-link>
                        </template>
                    </b-card>
                </div>

                <div class="col-lg-3 col-md-6 col-sm-12 mb-3"">
                    <b-card>
                        <b-card-text>
                            <h4 class="mt-2 mb-3">
                                <b-icon icon="globe" scale="0.8"></b-icon>
                                Nome
                            </h4>
                            <hr>
                            <p class="mt-3">xxx</p>
                        </b-card-text>
                        <template #footer>
                            <router-link to="#">
                                Manage
                            </router-link>
                        </template>
                    </b-card>
                </div>

                <div class="col-lg-3 col-md-6 col-sm-12 mb-3"">
                    <b-card>
                        <b-card-text>
                            <h4 class="mt-2 mb-3">
                                <b-icon icon="globe" scale="0.8"></b-icon>
                                Nome
                            </h4>
                            <hr>
                            <p class="mt-3">xxx</p>
                        </b-card-text>
                        <template #footer>
                            <router-link to="#">
                                Manage
                            </router-link>
                        </template>
                    </b-card>
                </div>
            </div>
        </div>
    </div>
</template>
