import BaseCheckbox from './Inputs/BaseCheckbox.vue'
import Radio from './Inputs/BaseRadio.vue'
import BaseInput from './Inputs/BaseInput.vue'

import BaseDropdown from './BaseDropdown.vue'
import Table from './Table.vue'

import Card from './Cards/Card.vue'
import ChartCard from './Cards/ChartCard.vue'
import StatsCard from './Cards/StatsCard.vue'

import SidebarPlugin from './SidebarPlugin'

let components = {
  BaseCheckbox,
  Radio,
  BaseInput,
  Card,
  ChartCard,
  StatsCard,
  Table,
  BaseDropdown,
  SidebarPlugin
}

export default components
